@@ -22,6 +22,7 @@
 
 #include "filename.h"
 #include "debug.h"
+#include "whichos.h"
 
 #include <ctype.h>
 #include <string.h>
@@ -197,7 +198,7 @@ use_path(const char *pth, const char *lf)
 {
    char *fnm;
    int len, len_total;
-   bool fAddSep = fFalse;
+   bool fAddSep = false;
 
    len = strlen(pth);
    len_total = len + strlen(lf) + 1;
@@ -210,7 +211,7 @@ use_path(const char *pth, const char *lf)
 #ifdef FNM_SEP_DRV
 	 if (pth[len - 1] != FNM_SEP_DRV) {
 #endif
-	    fAddSep = fTrue;
+	    fAddSep = true;
 	    len_total++;
 #ifdef FNM_SEP_DRV
 	 }
@@ -233,24 +234,18 @@ add_ext(const char *fnm, const char *ext)
 {
    char * fnmNew;
    int len, len_total;
-#ifdef FNM_SEP_EXT
-   bool fAddSep = fFalse;
-#endif
+   bool fAddSep = false;
 
    len = strlen(fnm);
    len_total = len + strlen(ext) + 1;
-#ifdef FNM_SEP_EXT
    if (ext[0] != FNM_SEP_EXT) {
-      fAddSep = fTrue;
+      fAddSep = true;
       len_total++;
    }
-#endif
 
    fnmNew = osmalloc(len_total);
    strcpy(fnmNew, fnm);
-#ifdef FNM_SEP_EXT
    if (fAddSep) fnmNew[len++] = FNM_SEP_EXT;
-#endif
    strcpy(fnmNew + len, ext);
    return fnmNew;
 }
@@ -315,32 +310,54 @@ fopen_portable(const char *pth, const char *fnm, const char *ext,
    FILE *fh = fopenWithPthAndExt(pth, fnm, ext, mode, fnmUsed);
    if (fh == NULL) {
 #if OS_UNIX
-      int f_changed = 0;
-      char *fnm_trans, *p;
-      fnm_trans = osstrdup(fnm);
-      for (p = fnm_trans; *p; p++) {
+      bool changed = false;
+      char *fnm_trans = osstrdup(fnm);
+      for (char *p = fnm_trans; *p; p++) {
 	 switch (*p) {
 	 case '\\': /* swap a backslash to a forward slash */
 	    *p = '/';
-	    f_changed = 1;
+	    changed = true;
 	    break;
 	 }
       }
-      if (f_changed)
+      if (changed)
 	 fh = fopenWithPthAndExt(pth, fnm_trans, ext, mode, fnmUsed);
 
-      /* as a last ditch measure, try lowercasing the filename */
+      /* To help users process data that originated on a case-insensitive
+       * filing system, try lowercasing the filename if not found.
+       */
       if (fh == NULL) {
-	 f_changed = 0;
-	 for (p = fnm_trans; *p ; p++) {
+	 bool had_lower = false;
+	 changed = false;
+	 for (char *p = fnm_trans; *p ; p++) {
 	    unsigned char ch = *p;
 	    if (isupper(ch)) {
 	       *p = tolower(ch);
-	       f_changed = 1;
+	       changed = true;
+	    } else if (islower(ch)) {
+	       had_lower = true;
 	    }
 	 }
-	 if (f_changed)
+	 if (changed)
 	    fh = fopenWithPthAndExt(pth, fnm_trans, ext, mode, fnmUsed);
+
+	 /* If that fails, try upper casing the initial character of the leaf. */
+	 if (fh == NULL) {
+	    char *leaf = strrchr(fnm_trans, '/');
+	    leaf = (leaf ? leaf + 1 : fnm_trans);
+	    if (islower((unsigned char)*leaf)) {
+	       *leaf = toupper((unsigned char)*leaf);
+	       fh = fopenWithPthAndExt(pth, fnm_trans, ext, mode, fnmUsed);
+	    }
+	    if (fh == NULL && had_lower) {
+	       /* Finally, try upper casing the filename if it wasn't all
+		* upper case to start with. */
+	       for (char *p = fnm_trans; *p ; p++) {
+		  *p = toupper((unsigned char)*p);
+	       }
+	       fh = fopenWithPthAndExt(pth, fnm_trans, ext, mode, fnmUsed);
+	    }
+	 }
       }
       osfree(fnm_trans);
 #endif
@@ -383,3 +400,62 @@ filename_delete_output(void)
       osfree(p);
    }
 }
+
+#if OS_WIN32
+
+/* NB "c:fred" isn't relative. Eg "c:\data\c:fred" won't work */
+bool
+fAbsoluteFnm(const char *fnm)
+{
+   /* <drive letter>: or \<path> or /<path>
+    * or \\<host>\... or //<host>/... */
+   unsigned char ch = (unsigned char)*fnm;
+   return ch == '/' || ch == '\\' ||
+       (ch && fnm[1] == ':' && (ch | 32) >= 'a' && (ch | 32) <= 'z');
+}
+
+#elif OS_UNIX
+
+bool
+fAbsoluteFnm(const char *fnm)
+{
+   return (fnm[0] == '/');
+}
+
+#endif
+
+/* fDirectory( fnm ) returns true if fnm is a directory; false if fnm is a
+ * file, doesn't exist, or another error occurs (eg disc not in drive, ...)
+ * NB If fnm has a trailing directory separator (e.g. “/” or “/home/olly/”
+ * then it's assumed to be a directory even if it doesn't exist (as is an
+ * empty string).
+ */
+
+#if OS_UNIX || OS_WIN32
+
+# include <sys/types.h>
+# include <sys/stat.h>
+# include <stdio.h>
+
+bool
+fDirectory(const char *fnm)
+{
+   struct stat buf;
+   if (!fnm[0] || fnm[strlen(fnm) - 1] == FNM_SEP_LEV
+#ifdef FNM_SEP_LEV2
+       || fnm[strlen(fnm) - 1] == FNM_SEP_LEV2
+#endif
+       ) return 1;
+   if (stat(fnm, &buf) != 0) return 0;
+#ifdef S_ISDIR
+   /* POSIX way */
+   return S_ISDIR(buf.st_mode);
+#else
+   /* BSD way */
+   return ((buf.st_mode & S_IFMT) == S_IFDIR);
+#endif
+}
+
+#else
+# error Unknown OS
+#endif
