@@ -143,7 +143,15 @@ class GLACanvas : public wxGLCanvas {
     int x_size;
     int y_size;
 
-#ifdef wxHAS_DPI_INDEPENDENT_PIXELS
+    // wxHAS_DPI_INDEPENDENT_PIXELS is new in 3.1.6.  In older versions we just
+    // always do the scaling which is slightly less efficient for platforms
+    // where pixel coordinates don't scale with DPI.
+#if defined wxHAS_DPI_INDEPENDENT_PIXELS || \
+    !wxCHECK_VERSION(3,1,6)
+# define HAS_DPI_INDEPENDENT_PIXELS
+#endif
+
+#ifdef HAS_DPI_INDEPENDENT_PIXELS
     double content_scale_factor = 1.0;
 #else
     static constexpr unsigned content_scale_factor = 1;
@@ -308,7 +316,7 @@ public:
 	return y_size;
     }
 
-#ifdef wxHAS_DPI_INDEPENDENT_PIXELS
+#ifdef HAS_DPI_INDEPENDENT_PIXELS
     double GetContentScaleFactor() const {
 	list_flags |= INVALIDATE_ON_HIDPI;
 	return content_scale_factor;
@@ -319,10 +327,10 @@ public:
 #else
     // wxWindow::GetContentScaleFactor() will always return 1.0, so arrange
     // things so it's a compile-time constant the compiler can optimise away.
-    //
-    // Dummy parameter here avoids an error due to mismatched return type
-    // compared to the wxWidgets method.
-    unsigned GetContentScaleFactor(bool = false) const { return 1; }
+    // Use a macro so we can return unsigned instead of double without a lot
+    // of pain from trying to override a virtual method while changing the
+    // return type.
+# define GetContentScaleFactor() 1u
     void UpdateContentScaleFactor() { }
 #endif
 
